@@ -2,10 +2,11 @@ from birdbrain_finch import BirdbrainFinch
 from birdbrain_hummingbird import BirdbrainHummingbird
 from birdbrain_microbit import BirdbrainMicrobit
 
-from BirdBrain import Hummingbird
-#from BirdBrain import *
+from BirdBrain import Finch,Hummingbird
 
 def test_instantiating_devices_old_way():
-    #finch = BirdbrainFinch('B')
+    finch = BirdbrainFinch('B')
     hummingbird = BirdbrainHummingbird('A')
+
+    finch = Finch('B')
     hummingbird = Hummingbird('A')
